@@ -41,7 +41,7 @@ function (tcl.list)
         length(rownumbers) != nrow(dataframe)) 
         stop("rownumbers argument must be TRUE, FALSE or have length nrow(dataframe)")
     require(tcltk) || stop("Tcl/Tk support is absent")
-    oldwidth <- options()$width
+    oldwidth <- unlist(options("width"))
     options(width = 10000)
     conn <- file()
     sink(conn)
@@ -49,6 +49,8 @@ function (tcl.list)
     sink()
     zz <- scan(conn, sep = "\n", what = character(0), quiet = TRUE)
     close(conn)
+    if (length(zz) > 1 + nrow(dataframe)) stop(
+       "data frame too wide")
     options(width = oldwidth)
     base <- tktoplevel()
     tkwm.geometry(base, placement)
